import type { Handle } from "@sveltejs/kit";
import type { I18nConfig } from "../adapter.js";
export type HandleOptions = {
    /**
     * Which placeholder to find and replace with the language tag.
     * Use this placeholder as the lang atrribute in your `src/app.html` file.
     *
     *
     * @default "%paraglide.lang%"
     *
     * @example
     * ```html
     * <!-- src/app.html -->
     * <html lang="%paraglide.lang%">
     * ```
     * ```ts
     * { langPlaceholder: "%paraglide.lang%" }
     * ```
     *
     */
    langPlaceholder?: string;
    /**
     * Which placeholder to find and replace with the text-direction of the current language.
     *
     * @default "%paraglide.textDirection%"
     *
     * @example
     * ```html
     * <!-- src/app.html -->
     * <html dir="%paraglide.textDirection%">
     * ```
     * ```ts
     * { textDirectionPlaceholder: "%paraglide.textDirection%" }
     * ```
     */
    textDirectionPlaceholder?: string;
};
export declare const createHandle: <T extends string>(i18n: I18nConfig<T>, options: HandleOptions) => Handle;
declare global {
    namespace App {
        interface Locals {
            paraglide: {
                lang: string;
                textDirection: "ltr" | "rtl";
            };
        }
    }
}
//# sourceMappingURL=handle.d.ts.map