import { escapeForDoubleQuotes } from "./escape.js";
export function ternary(predicate, consequent, alternate) {
    return `${predicate} ? ${consequent} : ${alternate}`;
}
/**
 * Returns code for an equality check between two values.
 *
 * @example
 *
 * eq("a", "b")
 * // -> '(a === b)'
 */
export function eq(first, second) {
    return `(${first} === ${second})`;
}
export function neq(first, second) {
    return `(${first} !== ${second})`;
}
export function and(first, second) {
    return `(${first} && ${second})`;
}
export function or(first, second) {
    return `(${first} || ${second})`;
}
export function str(value) {
    return `"${escapeForDoubleQuotes(value)}"`;
}
/**
 * Returns an attribute declaration for a given name and value.
 *
 * @example
 *
 * attribute("val", "a + b")
 * // -> 'val={a + b}'
 *
 */
export function attribute(name, value) {
    return `${name}={${value}}`;
}
export function spreadAttr(value) {
    return `{...(${value})}`;
}
